@@ -3,16 +3,12 @@ from refdatatypes.refbase import RefBase
 
 class RefStr(RefBase):
     def __init__(self, value_: str):
-        super().__init__()
-        self.value = value_
+        super().__init__(value_)
 
     @property
     def value(self) -> str:
-        return self._value[0]
+        return super().value
 
     @value.setter
     def value(self, value_: str):
-        self._value[0] = str(value_)
-
-    def __str__(self) -> str:
-        return self.value
+        super()._base_value_setter(str(value_))
